package in.sisoft.internalstorage;

import android.app.ProgressDialog;
import android.content.Context;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    EditText sharedData;
    TextView dataResults;
    FileOutputStream fos;
    String FILENAME = "InternalString123";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        setUpVaribales();
    }
    private void setUpVaribales() {
        sharedData = (EditText)findViewById(R.id.etSP);
        dataResults = (TextView)findViewById(R.id.tvShow);
        Button save = (Button)findViewById(R.id.bSave);
        Button load = (Button)findViewById(R.id.bLoad);
        save.setOnClickListener(this);
        load.setOnClickListener(this);
        try {
            fos = openFileOutput(FILENAME, Context.MODE_PRIVATE);
            fos.close();
        }
        catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onClick(View view) {
        switch (view.getId()){

            case R.id.bSave:
                String data = sharedData.getText().toString();

                try {
                    fos = openFileOutput(FILENAME,Context.MODE_PRIVATE);
                } catch (FileNotFoundException e) {
                    e.printStackTrace();
                }
                try {
                    fos.write(data.getBytes());
                } catch (IOException e) {
                    e.printStackTrace();
                }
                try {
                    fos.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }

                break;

            case R.id.bLoad:

                new loadSomeStuff().execute(FILENAME);
                break;
        }
    }

    private class loadSomeStuff extends AsyncTask<String,Integer,String> {


        ProgressDialog mProgressDialog;

        protected void onPreExecute(){
            mProgressDialog = new ProgressDialog(MainActivity.this);
            mProgressDialog.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
            mProgressDialog.setMax(100);
            mProgressDialog.show();
        }

        @Override
        protected String doInBackground(String... strings) {

            String collected = null;
            FileInputStream fileInputStream= null;

            for(int i = 0;i <20;i++){
                publishProgress(5);
                try {
                    Thread.sleep(100);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
            mProgressDialog.dismiss();

            try {
                fileInputStream = openFileInput(FILENAME);
                byte[] dataArray = new byte[fileInputStream.available()];
                while (fileInputStream.read(dataArray)!=-1){

                    collected = new String(dataArray);
                }
            } catch (IOException e) {
                e.printStackTrace();
            } finally {
                try {
                    fileInputStream.close();
                    return collected;
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            return null;
        }

        protected void onProgressUpdate(Integer...progress){
            mProgressDialog.incrementProgressBy(progress[0]);
        }

        protected void onPostExecute(String result){
            dataResults.setText(result);
        }
    }

}

/*
        AsyncTask enables proper and easy use of the UI thread.
        This class allows you to perform background operations and publish results on the UI thread
                without having to manipulate threads and/or handlers.
*/

        /*An asynchronous task is defined by a computation that runs on a background thread and whose
        result is published on the UI thread. An asynchronous task is defined by 3 generic types,
        called Params, Progress and Result, and 4 steps, called onPreExecute,
        doInBackground, onProgressUpdate and onPostExecute.

Params, the type of the parameters sent to the task upon execution.
Progress, the type of the progress units published during the background computation.
Result, the type of the result of the background computation.

Not all types are always used by an asynchronous task. To mark a type as unused, simply use the type Void:

 private class MyTask extends AsyncTask<Void, Void, Void> { ... }

 When an asynchronous task is executed, the task goes through 4 steps:

 1.onPreExecute(), invoked on the UI thread before the task is executed.
 This step is normally used to setup the task, for instance by showing a progress bar in the user interface.

2.doInBackground(Params...), invoked on the background thread immediately after onPreExecute() finishes executing.
 This step is used to perform background computation that can take a long time.
 The parameters of the asynchronous task are passed to this step.
  The result of the computation must be returned by this step and will be passed back to the last step.
   This step can also use publishProgress(Progress...) to publish one or more units of progress.
   These values are published on the UI thread, in the onProgressUpdate(Progress...) step.

   3.onProgressUpdate(Progress...), invoked on the UI thread after a call to publishProgress(Progress...).
   The timing of the execution is undefined.
   This method is used to display any form of progress in the user interface while the background computation is still executing.
    For instance, it can be used to animate a progress bar or show logs in a text field.

4.onPostExecute(Result), invoked on the UI thread after the background computation finishes.
The result of the background computation is passed to this step as a parameter.

preExecute() and postExecute() offer you access to GUI before and after the heavy
lifting occurs in this new thread, you can even pass the result of the long operation to postExecute()
 to then show any results of processing.

There are a few threading rules that must be followed for this class to work properly:

The AsyncTask class must be loaded on the UI thread. This is done automatically as of JELLY_BEAN.
The task instance must be created on the UI thread.
execute(Params...) must be invoked on the UI thread.
Do not call onPreExecute(), onPostExecute(Result), doInBackground(Params...), onProgressUpdate(Progress...) manually.
The task can be executed only once (an exception will be thrown if a second execution is attempted.)



*/
